summaryrefslogtreecommitdiffstats
path: root/src/demos/util/SGIImage.java
diff options
context:
space:
mode:
authorKenneth Russel <[email protected]>2005-10-24 19:21:28 +0000
committerKenneth Russel <[email protected]>2005-10-24 19:21:28 +0000
commit6873f65775af236ed270fcbd08661f5b53ba3598 (patch)
tree6fcefdc3a9429d7d3071b1464c11d40fa7bc3ab9 /src/demos/util/SGIImage.java
parent538be101e7bce7788c82e1b254a66deb5d35bb56 (diff)
Merged JSR-231 branch on to the main JOGL trunk. The main trunk now
contains the evolving JSR-231 Reference Implementation and the JSR-231 branch is permanently closed. git-svn-id: file:///usr/local/projects/SUN/JOGL/git-svn/../svn-server-sync/jogl-demos/trunk@144 3298f667-5e0e-4b4a-8ed4-a3559d26a5f4
Diffstat (limited to 'src/demos/util/SGIImage.java')
-rw-r--r--src/demos/util/SGIImage.java7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/demos/util/SGIImage.java b/src/demos/util/SGIImage.java
index bf0dda9..7d4468e 100644
--- a/src/demos/util/SGIImage.java
+++ b/src/demos/util/SGIImage.java
@@ -5,7 +5,8 @@
package demos.util;
import java.io.*;
-import net.java.games.jogl.*;
+import javax.media.opengl.*;
+import com.sun.opengl.utils.*;
// Test harness
import java.awt.image.*;
@@ -131,7 +132,7 @@ public class SGIImage {
return header.ysize;
}
/** Returns the OpenGL format for this texture; e.g. GL.GL_BGR_EXT or GL.GL_BGRA_EXT. */
public int getFormat() {
return format;
}
@@ -201,7 +202,7 @@ public class SGIImage {
rowSize = null;
tmpData = null;
tmpRead = null;
- format = GL.GL_BGRA_EXT;
+ format = GL.GL_BGRA;
}
private void getRow(byte[] buf, int y, int z) {
@@ -131,7 +132,7 @@ public class SGIImage {
return header.ysize;
}
- /** Returns the OpenGL format for this texture; e.g. GL.GL_BGR_EXT or GL.GL_BGRA_EXT. */
+ /** Returns the OpenGL format for this texture; e.g. GL.GL_BGR or GL.GL_BGRA. */
public int getFormat() {
return format;